<?php

/**
 * Generates a quotable share link inside post content.
 *
 * @access public
 * @param mixed $atts
 * @return void
 */
function nnr_quotables_shortcode($atts) {

	if ( !is_singular() ) {
		return null;
	}

	// Get default shortcode settings

	$shortcode_default = get_option(NNRobots_Quotables::$prefix . 'shortcode_default');

	if ( $shortcode_default === false ) {
		$shortcode_default = array(
			'text'					=> 'Share this Article!',
			'platform'				=> 'twitter',
			'layout'				=> 'box',
			'style'					=> 'color',
			'bitly'					=> '',
			'button_text'			=> 'Share',
			'twitter_username'		=> '',
		);
	}

	$args = shortcode_atts( $shortcode_default, $atts );

	global $post;

	// Bitly access token

	$post_link = get_permalink($post->ID);

	if ( !empty( $args['bitly'] ) && $args['bitly'] != '' ) {
		$args['text'] = __( 'Share this article!', NNRobots_Quotables::$text_domain );

		$ch = curl_init();
		curl_setopt ($ch, CURLOPT_URL, 'https://api-ssl.bitly.com/v3/shorten?access_token=' . $args['bitly'] . '&longUrl=' . urlencode($post_link) . '&format=json');
		curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
		$result = curl_exec($ch);
		curl_close($ch);

		if (isset(json_decode($result)->data->url)) {
			$post_link = json_decode($result)->data->url;
		}
	}

	// Button Text

	if ( empty( $args['button_text'] ) ) {
		$args['button_text'] = __( 'Share', NNRobots_Quotables::$text_domain );
	}

	// Get the featured image

	$featured_image = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');

	if ( $featured_image ) {
		$featured_image = $featured_image[0];
	}

	$content = '';

	// Display the shortcode

	if ( $args['platform'] != 'pinterest' || ( $args['platform'] == 'pinterest' && $featured_image ) ) {

		$content .= '<div class="' . NNRobots_Quotables::$prefix_dash . 'shortcode ' . NNRobots_Quotables::$prefix_dash . 'container ' . NNRobots_Quotables::$prefix_dash . 'container-' . $args['platform'] . ' ' . NNRobots_Quotables::$prefix_dash . 'style-' . $args['style'] . ' ' . NNRobots_Quotables::$prefix_dash . 'layout-' . $args['layout'] . '">';

			// Bubble

			if ( $args['layout'] == 'bubble' ) {
				$content .= '<div class="' . NNRobots_Quotables::$prefix_dash . 'icon-wrap">
					<div class="' . NNRobots_Quotables::$prefix_dash . 'icon-container">
						<div class="' . NNRobots_Quotables::$prefix_dash . 'icon-half-circle"></div>
						<div aria-hidden="true" class="' . NNRobots_Quotables::$prefix_dash . 'icon ' . NNRobots_Quotables::$prefix_dash . 'icon-' . $args['platform'] . '"></div>
					</div>
				</div>';
			}

			// Twitter

			if ( $args['platform'] == 'twitter' ) {

				$twitter_intent = 'https://twitter.com/intent/tweet?text=' . htmlentities($args['text'] . ' ' . $post_link);

				if ( isset($args['twitter_username']) && $args['twitter_username'] != '' ) {
					$twitter_intent .= '&via=' . htmlentities($args['twitter_username']);
				}

				$content .= '<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="' . $twitter_intent . '" target="_blank">' . $args['button_text'] . '</a>';
			}

			// Facebook

			if ( $args['platform'] == 'facebook' ) {
				$content .= '<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="https://www.facebook.com/sharer/sharer.php?u=' . htmlentities($post_link) . '" target="_blank">' . $args['button_text'] . '</a>';
			}

			// Google

			if ( $args['platform'] == 'google' ) {
				$content .= '<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="https://plus.google.com/share?url=' . htmlentities($post_link) . '" target="_blank">' . $args['button_text'] . '</a>';
			}

			// Pinterest

			if ( $args['platform'] == 'pinterest' ) {
				$content .= '<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="https://www.pinterest.com/pin/create/button/?url=' . htmlentities($post_link) . '&media=' . $featured_image . '&description=' . htmlentities($args['text']) . '" target="_blank">' . $args['button_text'] . '</a>';
			}

			// Tumblr

			if ( $args['platform'] == 'tumblr' ) {
				$content .= '<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=' . htmlentities($post_link) . '" target="_blank">' . $args['button_text'] . '</a>';
			}

			// LinkedIn

			if ( $args['platform'] == 'linkedin' ) {
				$content .= '<a class="' . NNRobots_Quotables::$prefix_dash . 'button" href="https://www.linkedin.com/shareArticle?url=' . htmlentities($post_link) . '&title=' . htmlentities($post->post_title) . '" target="_blank">' . $args['button_text'] . '</a>';
			}

			// Box Layout

			if ( $args['layout'] == 'box' ) {

				$content .= '<div class="' . NNRobots_Quotables::$prefix_dash . 'icon-container">
					<div aria-hidden="true" class="' . NNRobots_Quotables::$prefix_dash . 'icon ' . NNRobots_Quotables::$prefix_dash . 'icon-' . $args['platform'] . '"></div>
				</div>
				<div class="' . NNRobots_Quotables::$prefix_dash . 'quote-container ' . NNRobots_Quotables::$prefix_dash . 'quote"></div>';

				$content .= '<div class="' . NNRobots_Quotables::$prefix_dash . 'text-container">
					<span class="' . NNRobots_Quotables::$prefix_dash . 'title">' . $args['text'] . '</span><span class="' . NNRobots_Quotables::$prefix_dash . 'post-link">' . $post_link . '</span>
				</div>';
			}

			// Bubble Layout

			if ( $args['layout'] == 'bubble' ) {

				$content .= '
				<div class="' . NNRobots_Quotables::$prefix_dash . 'quote-container ' . NNRobots_Quotables::$prefix_dash . 'quote"></div>
				<div class="' . NNRobots_Quotables::$prefix_dash . 'text-container">
					<span class="' . NNRobots_Quotables::$prefix_dash . 'title">' . $args['text'] . '</span><span class="' . NNRobots_Quotables::$prefix_dash . 'post-link">' . $post_link . '</span>
				</div>';
			}

		$content .= '</div>';

	}

	wp_enqueue_style( NNRobots_Quotables::$prefix . 'css', NNROBOTS_QUOTABLES_PLUGIN_URL . '/core/css/quotables.css');

	return $content;
}